@@ -18,7 +18,7 @@
    If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-   Author: Jaka Mocnik <jaka.mocnik@kiss.uni-lj.si>
+   Author: Jaka Mocnik <jaka@gnu.org>
 */
 
 #include <config.h>
@@ -69,26 +69,29 @@ static GtkWidget *get_font_label(const gchar *name, gdouble size) {
 
 static void font_button_clicked(GtkWidget *button, GnomeFont **font) {
 	static GtkWidget *fsd = NULL;
+	static GtkWidget *fontsel = NULL;
 	const gchar *f_name;
 	gdouble f_size;
 
 	if(!fsd) {
 		fsd = gnome_font_selection_dialog_new(_("Select font"));
+		fontsel = gnome_font_selection_dialog_get_fontsel (GNOME_FONT_SELECTION_DIALOG(fsd));
 		gtk_window_set_modal(GTK_WINDOW(fsd), TRUE);
 		gnome_dialog_close_hides(GNOME_DIALOG(fsd), TRUE);
 	}
 	if(*font)
-		gnome_font_selection_dialog_set_font(GNOME_FONT_SELECTION_DIALOG(fsd),
-											 *font);
+		gnome_font_selection_set_font(GNOME_FONT_SELECTION (fontsel),
+									  *font);
+
 	gtk_widget_show(fsd);
 	if(gnome_dialog_run_and_close(GNOME_DIALOG(fsd)) == 0) {
-		GnomeDisplayFont *disp_font;
-		disp_font = gnome_font_selection_dialog_get_font(GNOME_FONT_SELECTION_DIALOG(fsd));
+		GnomeFont *disp_font;
+		disp_font = gnome_font_selection_get_font (GNOME_FONT_SELECTION(fontsel));
 		if(*font)
 			gtk_object_unref(GTK_OBJECT(*font));
-		*font = disp_font->gnome_font;
+		*font = disp_font;
 		f_name = gnome_font_get_name(*font);
-		f_size = (*font)->size;
+		f_size = gnome_font_get_size(*font);
 		gtk_container_remove(GTK_CONTAINER(button), GTK_BIN(button)->child);
 		gtk_container_add(GTK_CONTAINER(button), get_font_label(f_name, f_size));
 	}
@@ -524,11 +527,14 @@ static void apply_changes_cb(GnomePropertyBox *pbox, gint page, PropertyUI *pui)
 			( (offset_fmt[i] >= 'a' && offset_fmt[i] <= 'z') ||
 			  (offset_fmt[i] >= 'A' && offset_fmt[i] <= 'Z') ) ) {
 			expect_spec = FALSE;
-			if(offset_fmt[i] != 'x' && offset_fmt[i] != 'd' && offset_fmt[i] != 'o') {
+			if(offset_fmt[i] != 'x' && offset_fmt[i] != 'd' &&
+			   offset_fmt[i] != 'o' && offset_fmt[i] != 'X' &&
+			   offset_fmt[i] != 'P' && offset_fmt[i] != 'p') {
 				g_free(offset_fmt);
 				offset_fmt = old_offset_fmt;
 				gtk_entry_select_region(GTK_ENTRY(pui->format), i, i+1);
-				gnome_error_dialog_parented(_("The offset format string contains format specifier other than 'x', 'd' or 'o'!"),
+				gnome_error_dialog_parented(_("The offset format string contains invalid format specifier.\n"
+											  "Only 'x', 'X', 'p', 'P', 'd' and 'o' are allowed."),
 											GTK_WINDOW(pui->pbox));
 				gtk_window_set_focus(GTK_WINDOW(pui->pbox), pui->format);
 				break;
@@ -574,13 +580,13 @@ static void apply_changes_cb(GnomePropertyBox *pbox, gint page, PropertyUI *pui)
 		if(data_font_name)
 			g_free(data_font_name);
 		data_font_name = g_strdup(gnome_font_get_name(GNOME_FONT(pui->data_font)));
-		data_font_size = GNOME_FONT(pui->data_font)->size;
+		data_font_size = gnome_font_get_size(GNOME_FONT(pui->data_font));
 	}
 	if(pui->header_font) {
 		if(header_font_name)
 			g_free(header_font_name);
 		header_font_name = g_strdup(gnome_font_get_name(GNOME_FONT(pui->header_font)));
-		header_font_size = GNOME_FONT(pui->header_font)->size;
+		header_font_size = gnome_font_get_size(GNOME_FONT(pui->header_font));
 	}
 }
 
